@@ -124,10 +124,10 @@ class fMMS_GUI(hildon.Program):
 	def create_about_dialog(self):
 		dialog = gtk.AboutDialog()                                                 
 		dialog.set_name("fMMS")
-		fmms_logo = gtk.gdk.pixbuf_new_from_file("fmms.png")
+		fmms_logo = gtk.gdk.pixbuf_new_from_file("/opt/fmms/fmms.png")
 		dialog.set_logo(fmms_logo)                                   
 		dialog.set_comments('MMS send and receive support for Fremantle')                      
-		dialog.set_version("0.1.1")                                                
+		dialog.set_version(self.config.get_version())                                                
 		dialog.set_copyright("By Nick Leppänen Larsson (aka frals)")                    
 		dialog.set_website("http://mms.frals.se/")                                  
 		dialog.connect("response", lambda d, r: d.destroy())                      
